aboutsummaryrefslogtreecommitdiffhomepage
path: root/include
diff options
context:
space:
mode:
authorGravatar bsalomon <bsalomon@google.com>2015-09-09 09:48:06 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2015-09-09 09:48:06 -0700
commit1fcc01c4158bd68c679569e6c7cfbb302d0ce170 (patch)
tree2d3d41bf771e9433ed6a26b0e2e710f1c87a5391 /include
parent5ca4fa3846067a47e88d35ace895df3ebe3ec2a5 (diff)
GrPathRangeBatch
Diffstat (limited to 'include')
-rw-r--r--include/gpu/GrDrawContext.h19
1 files changed, 7 insertions, 12 deletions
diff --git a/include/gpu/GrDrawContext.h b/include/gpu/GrDrawContext.h
index 552cfd3dc8..aae4bf00b3 100644
--- a/include/gpu/GrDrawContext.h
+++ b/include/gpu/GrDrawContext.h
@@ -18,7 +18,7 @@ class GrDrawBatch;
class GrDrawTarget;
class GrPaint;
class GrPathProcessor;
-class GrPathRange;
+class GrPathRangeDraw;
class GrPipelineBuilder;
class GrRenderTarget;
class GrStrokeInfo;
@@ -61,17 +61,12 @@ public:
SkScalar x, SkScalar y,
SkDrawFilter*, const SkIRect& clipBounds);
- // drawPaths is thanks to GrStencilAndCoverTextContext
- // TODO: remove
- void drawPaths(GrPipelineBuilder* pipelineBuilder,
- const GrPathProcessor* pathProc,
- const GrPathRange* pathRange,
- const void* indices,
- int /*GrDrawTarget::PathIndexType*/ indexType,
- const float transformValues[],
- int /*GrDrawTarget::PathTransformType*/ transformType,
- int count,
- int /*GrPathRendering::FillType*/ fill);
+ // drawPathsFromRange is thanks to GrStencilAndCoverTextContext
+ // TODO: remove once path batches can be created external to GrDrawTarget.
+ void drawPathsFromRange(const GrPipelineBuilder*,
+ const GrPathProcessor*,
+ GrPathRangeDraw* draw,
+ int /*GrPathRendering::FillType*/ fill);
/**
* Provides a perfomance hint that the render target's contents are allowed